@@ -24,6 +24,7 @@ from requests.packages.urllib3.util.retry import Retry
 
 import  inforion.ionapi.controller as controller
 
+import inforion.helper.filehandling as filehandling
 
 #import sendresults, saveresults
 #from inforion.ionapi.model import 
@@ -34,7 +35,10 @@ MaxChunk = 150
 
 
 def execute(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
-    df = pd.read_csv(inputfile)
+    
+    ext = filehandling.checkfiletype(inputfile)
+    df = filehandling.loadfile(ext,inputfile)
+    #df = pd.read_csv(inputfile)
     #df = pd.read_excel(inputfile)
     
 
