@@ -1,12 +1,12 @@
 # Transformation of Staging Data into M3 format via mapping file 
-import pandas as pa
+import pandas as pd
 import json
 import numpy as np
 
-def tranform_data(mappingfile, mainsheet,stagingdata):
+def tranform_data(mappingfile, mainsheet,stagingdata,outputfile=None):
 
     # Read the file from given location
-    xls = pa.ExcelFile(mappingfile)
+    xls = pd.ExcelFile(mappingfile)
 
     # to read all sheets to a map
     sheet_to_df_map = {}
@@ -36,4 +36,13 @@ def tranform_data(mappingfile, mainsheet,stagingdata):
                     elif row[36] == 'const':
                         row_dict[row[15]] = str(row[37])
         rows_list.append(row_dict)
-    return pa.DataFrame(rows_list).replace('nan', '', regex=True)
\ No newline at end of file
+    
+    df = pd.DataFrame(rows_list).replace('nan', '', regex=True)
+
+    if outputfile is not None:
+        print ('Save to file: ' + outputfile)
+        writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
+        df.to_excel(writer, sheet_name='Log Output',index=False)
+        writer.save()
+
+    return df
\ No newline at end of file
